@@ -4,7 +4,7 @@ package Config::Constants;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my %CONFIG_LOADER_CLASSES = (
     perl => 'Config::Constants::Perl',
@@ -33,46 +33,7 @@ sub import {
         # try to load the config ...
         $CONFIG = eval { $config_loader_class->new($file) };
         die "Failed to load config (type => $type, file => $file) : $@" if $@;
-        # now load the consants ...
-        no strict 'refs';
-        foreach my $module ($CONFIG->modules()) {
-            foreach my $constant ($CONFIG->constants($module)) {
-                my ($name, $value) = each %{$constant};
-                if (defined &{"${module}::$name"}) {
-                    # since this already exists, we 
-                    # assume that it is a valid constant
-                    # and that our module was already
-                    # loaded
-                    no warnings;
-                    *{"${module}::$name"} = sub () { $value };    
-                    delete $CHECKED_CONSTANTS{$module}->{$name};
-                }
-                else {
-                    # since this does not exist, then our
-                    # module may not have been loaded yet.
-                    # but in order to determine this,
-                    # we have to see if the constants have
-                    # been registered yet ...
-                    if (exists $CHECKED_CONSTANTS{$module}) {
-                        # this means our module was loaded first, and
-                        # the constants were registered. Now, if 
-                        # we do not see this particular constant 
-                        # in here, then we need to throw an exception
-                        die "Unknown constant for '$module' -> ($name)"
-                            unless exists $CHECKED_CONSTANTS{$module}->{$name};
-                    }
-                    else {
-                        # being in this block means that is is unlikely 
-                        # the conf has been loaded yet, so we will 
-                        # just create our constants, and make a note
-                        # of each of them so that they can be 
-                        # checked later on.
-                        $UNCHECKED_CONSTANTS{$module} = { $name => undef };                                        
-                        *{"${module}::$name"} = sub () { $value };                    
-                    }
-                }            
-            }
-        }
+        _load_all_modules();
     }
     else { 
         my $calling_pkg = caller();
@@ -90,7 +51,7 @@ sub import {
                 join(", " => keys(%{$UNCHECKED_CONSTANTS{$calling_pkg}})) . 
                 ")" if keys %{$UNCHECKED_CONSTANTS{$calling_pkg}};
         }
-        else {
+        else {    
             # this means the conf has not been loaded yet, 
             # so we need to build a list of acceptable 
             # constants to check against.
@@ -102,7 +63,7 @@ sub import {
             # NOTE: this means that the config was 
             # loaded before the module itself was
             # loaded, so we don't want to overwrite
-            next if defined &{"${calling_pkg}::$arg"};
+            next if defined &{"${calling_pkg}::$arg"};         
             # However, if it hasn't been defined, then
             # we want to do so. This will create a 
             # stub sub which will die if it is not 
@@ -124,11 +85,55 @@ sub import {
 #    print "CHECKED: "   . Dumper \%CHECKED_CONSTANTS;     
 #}
 
+## Private Utility Functions
+
+sub _load_all_modules {
+    foreach my $module ($CONFIG->modules()) {
+        _load_module($module);
+    }
+}
+
+sub _load_module {
+    my $module = shift;
+    no strict 'refs';    
+    foreach my $constant ($CONFIG->constants($module)) {
+        my ($name, $value) = each %{$constant};
+        if (defined &{"${module}::$name"}) {
+            # since this already exists, we 
+            # assume that it is a valid constant
+            # and that our module was already
+            # loaded
+            no warnings;
+            *{"${module}::$name"} = sub () { $value };    
+            delete $CHECKED_CONSTANTS{$module}->{$name};
+        }
+        else {
+            # since this does not exist, then our
+            # module may not have been loaded yet.
+            # but in order to determine this,
+            # we have to see if the constants have
+            # been registered yet ...
+            if (exists $CHECKED_CONSTANTS{$module}) {
+                # this means our module was loaded first, and
+                # the constants were registered. Now, if 
+                # we do not see this particular constant 
+                # in here, then we need to throw an exception
+                die "Unknown constant for '$module' -> ($name)"
+                    unless exists $CHECKED_CONSTANTS{$module}->{$name};
+            }
+            else {
+                # being in this block means that is is unlikely 
+                # the conf has been loaded yet, so we will 
+                # just create our constants, and make a note
+                # of each of them so that they can be 
+                # checked later on.
+                $UNCHECKED_CONSTANTS{$module} = { $name => undef };                                        
+                *{"${module}::$name"} = sub () { $value };                    
+            }
+        }            
+    }    
+}
 
-#sub handler {
-#    my $r = shift;
-#    # ... TODO
-#}
 
 1;
 
@@ -178,7 +183,7 @@ Config::Constants - Configuration variables as constants
 
 =head1 DESCRIPTION
 
-Using configuration files can help to make you code more flexible. However, this flexiblity comes at a cost of reading and parsing the configuration file, and then making the the configuration information available to your application. Most times this is a trade off which is well worth the price, and which works well is many situations.
+Using configuration files can help to make you code more flexible. However, this flexiblity comes at a cost of reading and parsing the configuration file, and then making the configuration information available to your application. Most times this is a trade off which is well worth the price, and which works well in many situations.
 
 However, sometimes what you want to configure is really very simple, and it can feel like overengineering to have to use a config object instance and fetch the config variable, and that is where this module comes into play.
 
@@ -230,6 +235,12 @@ You will still be able to access Foo's version of C<BAZ> via either a SUPER:: ca
 
 =back
 
+=head2 Interaction with Apache & mod_perl
+
+When developing with mod_perl is it useful to use a module like L<Apache::Reload> to help reload modules which have been changed. Because of the way B<Config::Constants> handles loading of constants, this should not require the config to be reloaded. However, if the config file itself is changed, it will require you to restart Apache in order for those changes to take effect. 
+
+Future plans include making a mod_perl handler which can be used to automatically reload the config file if it is modified.
+
 =head1 METHODS
 
 =over 4
@@ -246,6 +257,8 @@ You will still be able to access Foo's version of C<BAZ> via either a SUPER:: ca
 
 =item More tests
 
+=item re-write the docs, they are horrid
+
 =back
 
 =head1 BUGS
@@ -259,12 +272,12 @@ I use B<Devel::Cover> to test the code coverage of my tests, below is the B<Deve
  ----------------------------------- ------ ------ ------ ------ ------ ------ ------
  File                                  stmt branch   cond    sub    pod   time  total
  ----------------------------------- ------ ------ ------ ------ ------ ------ ------
- Config/Constants.pm                   95.0   90.9    n/a   70.0    n/a   34.5   91.3
- Config/Constants/Perl.pm             100.0   50.0   33.3  100.0  100.0   17.0   82.0
- Config/Constants/XML.pm              100.0   50.0   33.3  100.0    n/a   26.2   90.6
- Config/Constants/XML/SAX/Handler.pm   96.7   81.2    n/a  100.0  100.0   22.4   92.5
+ Config/Constants.pm                   95.2   90.9    n/a   75.0    n/a   31.6   91.8
+ Config/Constants/Perl.pm             100.0   50.0   33.3  100.0  100.0   23.8   82.0
+ Config/Constants/XML.pm              100.0   50.0   33.3  100.0    n/a   23.9   90.6
+ Config/Constants/XML/SAX/Handler.pm   96.7   82.4    n/a  100.0  100.0   20.7   92.7
  ----------------------------------- ------ ------ ------ ------ ------ ------ ------
- Total                                 97.0   78.8   33.3   90.6  100.0  100.0   90.0
+ Total                                 97.0   79.4   33.3   91.2  100.0  100.0   90.3
  ----------------------------------- ------ ------ ------ ------ ------ ------ ------
 
 =head1 SEE ALSO
@@ -289,4 +302,3 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
 =cut
-
